<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	xmlns:ns          ="http://services.natureserve.org/docs/schemas/biodiversityDataFlow/1"
	xmlns:xsi         ="http://www.w3.org/2001/XMLSchema-instance">
    <xsl:output method="html"/>
    <xsl:strip-space elements="*"/>

    <xsl:template match="ns:schemaDocumentation">
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="ns:documentationHtmlWeakLineBreak"/>


    <xsl:template match="ns:schemaDocumentationHeader">
        <html>
            <xsl:comment>
                !!! ABSOLUTELY POSITIVELY DO NOT EDIT THIS DOCUMENT !!!

                The data in this document are maintained in a source XML document, which may or may not
                be generated from a database. Editing this document is a temporary measure that you should
                avoid. Edit the related content in the source XML if you want your change to stick.
            </xsl:comment>
            
            <head>
                <title>
                    <xsl:value-of select="ns:schemaHtmlHeadTitle" disable-output-escaping="yes"/>
                </title>
                <link rel="stylesheet" href="print.css" type="text/css" media="all" />
            </head>
            <body>
                <h1 class="documentTitle"><xsl:value-of select="ns:schemaHtmlHeadTitle" disable-output-escaping="yes"/></h1>

                <table border="0" cellspacing="0" cellpadding="4">
                    <xsl:apply-templates/>
                </table>

            </body>
        </html>

    </xsl:template>
    <xsl:template match="ns:schemaHtmlHeadTitle"/>

    <xsl:template match="ns:schemaDescription">
        <tr class="schema_description">
            <td class="definition_term">Description:</td>
            <td class="definition_detail"><xsl:value-of select="." disable-output-escaping="yes"/></td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:descriptionAddenda">
        <tr class="schema_description">
            <td class="definition_term"/>
            <td class="definition_detail"><xsl:value-of select="." disable-output-escaping="yes"/></td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:schemaStatusDetails">
        <tr class="schema_status">
            <td class="definition_term">Status:</td>
            <td class="definition_detail">
                <ul>
                    <xsl:apply-templates/>
                </ul>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:schemaStatus">
        <li><xsl:value-of select="."/></li>
    </xsl:template>
    <xsl:template match="ns:schemaSubmissionDetails">
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="ns:submittedBy">
        <tr class="schema_description">
            <td class="definition_term">Submitted By:</td>
            <td class="definition_detail"><xsl:value-of select="." disable-output-escaping="yes"/></td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:submissionDate">
        <tr class="schema_description">
            <td class="definition_term">Submission Date:</td>
            <td class="definition_detail"><xsl:value-of select="." disable-output-escaping="yes"/></td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:changeLogDetails">
        <tr class="schema_status">
            <td class="definition_term">Change Log:</td>
            <td class="definition_detail">
                <ul>
                    <xsl:apply-templates/>
                </ul>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:changeNote">
        <li><xsl:value-of select="@changeDate"/> - <xsl:value-of select="." disable-output-escaping="yes"/></li>
    </xsl:template>
    <xsl:template match="ns:schemaReviewQuestions">
        <tr class="schema_status">
            <td class="definition_term">Open Questions:</td>
            <td class="definition_detail">
                <xsl:apply-templates/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:generalQuestionDetails">
        <b>General Questions:</b>
        <ul>
            <xsl:apply-templates/>
        </ul>
    </xsl:template>
    <xsl:template match="ns:generalQuestion">
        <li><xsl:value-of select="@questionDate"/> - <xsl:value-of select="." disable-output-escaping="yes"/></li>
    </xsl:template>
    <xsl:template match="ns:dataQuestionDetails">
        <b>Data Questions:</b>
        <ul>
            <xsl:apply-templates/>
        </ul>
    </xsl:template>
    <xsl:template match="ns:dataQuestion">
        <li><xsl:value-of select="@questionDate"/> - <xsl:value-of select="." disable-output-escaping="yes"/></li>
    </xsl:template>
    <xsl:template match="ns:technicalQuestionDetails">
        <b>Technical Questions:</b>
        <ul>
            <xsl:apply-templates/>
        </ul>
    </xsl:template>
    <xsl:template match="ns:technicalQuestion">
        <li><xsl:value-of select="@questionDate"/> - <xsl:value-of select="." disable-output-escaping="yes"/></li>
    </xsl:template>
    <xsl:template match="ns:schemaGeneralNoteDetails">
        <tr class="schema_status">
            <td class="definition_term">General Notes:</td>
            <td class="definition_detail">
                <ul>
                    <xsl:apply-templates/>
                </ul>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="ns:schemaGeneralNote">
        <li><xsl:value-of select="."/></li>
    </xsl:template>

    <xsl:template match="ns:schemaDocumentationDetails">
        <table class="definition_table" border="1" cellspacing="0" cellpadding="4">
            <xsl:apply-templates/>
        </table>
    </xsl:template>
    <xsl:template match="ns:documentationColumnHeadings">
        <thead class="definition_heading">
            <xsl:apply-templates/>
        </thead>
    </xsl:template>

    <xsl:template match="ns:documentationDetails">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="ns:documentationGroup">
        <tr class="definition_group">
		    <td valign="top" colspan="7"><xsl:value-of select="@name"/></td>
        </tr>
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="ns:documentationItem">
        <tr class="definition_row">
            <xsl:apply-templates/>
        </tr>
    </xsl:template>

    <xsl:template match="ns:dataElementName">
        <td class="definition_element"><xsl:value-of select="." disable-output-escaping="yes"/></td>
    </xsl:template>

    <xsl:template match="ns:dataElementDescription">
        <xsl:choose>
            <xsl:when test="./text()">
                <td class="definition_description"><xsl:value-of select="." disable-output-escaping="yes"/></td>
            </xsl:when>
            <xsl:otherwise>
                <td class="definition_description"><br/></td>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="ns:nonDescriptiveNotes">
        <xsl:choose>
            <xsl:when test="./text()">
                <td class="definition_notes"><xsl:value-of select="." disable-output-escaping="yes"/></td>
            </xsl:when>
            <xsl:otherwise>
                <td class="definition_notes"><br/></td>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="ns:xpath">
        <td class="definition_xpath">
            <xsl:call-template name="do-replace">
                <xsl:with-param name="text" select="."/>
            </xsl:call-template>
        </td>
    </xsl:template>

    <xsl:template name="do-replace">
        <xsl:param name="text"/>
        <xsl:variable name="to-replace" select="string('|')"/>
        <xsl:choose>
            <xsl:when test="contains($text, $to-replace)">
                <xsl:variable name="prefix">
                    <xsl:value-of select="substring-before($text, $to-replace)" disable-output-escaping="yes"/><xsl:value-of select="//ns:documentationHtmlWeakLineBreak" disable-output-escaping="yes"/>/
                </xsl:variable>
                <xsl:variable name="suffix">
                    <xsl:value-of select="substring-after($text, $to-replace)" disable-output-escaping="yes"/>
                </xsl:variable>
                <xsl:call-template name="do-replace">
                    <xsl:with-param name="text" select="concat( normalize-space($prefix) , normalize-space($suffix))"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$text" disable-output-escaping="yes"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


</xsl:stylesheet>